smvceviz
========
[![Downloads](https://pypip.in/download/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)
[![Latest Version](https://pypip.in/version/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)
[![Supported Python versions](https://pypip.in/py_versions/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)
[![Supported Python implementations](https://pypip.in/implementation/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)
[![Development Status](https://pypip.in/status/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)
[![Download format](https://pypip.in/format/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)
[![License](https://pypip.in/license/smvceviz/badge.svg)](https://pypi.python.org/pypi/smvceviz/)

Visualize the Traces of NuSMV and NuXMV
